//---------------------------------------------------------------------------
#ifndef bookmarkfrmH
#define bookmarkfrmH
//---------------------------------------------------------------------------
#include <vcl\Classes.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Forms.hpp>
#include <vcl\ComCtrls.hpp>
#include <swconfig.h>
#include <vcl\Menus.hpp>
#include <list>

using namespace sword;
using namespace std;

//---------------------------------------------------------------------------
class TbookmarkForm : public TForm
{
__published:	// IDE-managed Components
	TTreeView *bmtree;
	TPopupMenu *BMPopup;
	TMenuItem *Delete1;
	TMenuItem *AddChild1;
	TMenuItem *Rename1;
	TMenuItem *N1;
	TMenuItem *NewBookmarkFile1;
	void __fastcall bmtreeDragDrop(TObject *Sender, TObject *Source, int X, int Y);
	void __fastcall bmtreeDragOver(TObject *Sender, TObject *Source, int X, int Y,
	TDragState State, bool &Accept);
	void __fastcall bmtreeDblClick(TObject *Sender);
	void __fastcall AddChild1Click(TObject *Sender);
	void __fastcall Delete1Click(TObject *Sender);
	void __fastcall Rename1Click(TObject *Sender);
	void __fastcall NewBookmarkFile1Click(TObject *Sender);
private:	// User declarations
	void AddSection(SWConfig *config, TTreeView *tree, TTreeNode *parent, String section);
	list <String *> bmfiles;	// so we can delete each display we create
	

public:		// User declarations
	SWBuf bmdir;
	__fastcall TbookmarkForm(TComponent* Owner);
	__fastcall ~TbookmarkForm();
	void SaveBookmarks();
	void AddSectionToConf(SWConfig *config, String section, TTreeNode *tree);
};
//---------------------------------------------------------------------------
extern TbookmarkForm *bookmarkForm;
//---------------------------------------------------------------------------
#endif
 